dot-is_timezone: Check if a timezone specification is likely to work

Description Usage Arguments Value Examples

Description

Compares a candidate timezone string to the list of recognized time zones in the OlsonNames() list. available in base R. While this is not necessarily a complete list of valid time zones (which issystem-specific), it's a good portlable starting point.

Usage

1
.is_timezone(.timezone)

Arguments

timezone

Value

Boolean.

Examples

1
.is_timezone(c('Etc/GMT+5', 'EST', 'America/New_York'))

ccb60/SLRSIM documentation built on Jan. 21, 2022, 1:31 a.m.